@@ -46,7 +46,8 @@ def gen_image_class(image_path, baseurl=None):
             self.textbox = Box(pt.x + size[0] / 2, pt.y - size[1] / 2,
                                pt.x + size[0] / 2 + width, pt.y + size[1] / 2)
 
-            size = self.metrics.textsize(node.label, self.metrics.font_for(None),
+            size = self.metrics.textsize(node.label,
+                                         self.metrics.font_for(None),
                                          self.textbox.width)
 
             self.connectors[0] = XY(pt.x, self.image_box[1])
@@ -56,14 +57,14 @@ def gen_image_class(image_path, baseurl=None):
 
         def render_shape(self, drawer, format, **kwargs):
             if not kwargs.get('shadow'):
-                drawer.loadImage(image_url, self.image_box)
+                drawer.image(self.image_box, image_url)
                 drawer.rectangle(self.image_box, outline='black')
 
     return NationalFlagImage
 
 
 def to_classname(filename):
-    #137px-Flag_of_Lithuania.svg.png 
+    # 137px-Flag_of_Lithuania.svg.png
     filename = re.sub('.svg.png', '', filename)
     filename = re.sub('.*Flag_of_', '', filename)
     filename = re.sub('-', '_', filename)
